# Generated by roxygen2: do not edit by hand

export(dewens)
export(dewens_k)
export(ewens_mle)
export(gcrp)
export(rewens)
export(rgem)
importFrom(stats,rbeta)
importFrom(stats,uniroot)
useDynLib(ewens, .registration = TRUE)
